*********************************************************************
**
** 		    Fighter2: Basic sample Code for a platformer game.
** 		    Created : 11.27.00
**		    Pieced together by: 
**		           Chris Vick, nimtene@juno.com
**		    	
*********************************************************************

PATH "C:\bll\"			 ; The file pathway. 

DOUBLEBUFFER    set 1          ; 1 =  set double-buffering
Baudrate        set 9600
TEST            set 1
               
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		    Include important macros and variable
;;              files from bll kit.		    
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

		    include "macros\hardware.asm"

                include "macros\help.mac"
                include "macros\if_while.mac"
                include "macros\font.mac"
                include "macros\window.mac"
                include "macros\mikey.mac"
                include "macros\suzy.mac"
                include "macros\newkey.mac"
	
                include "vardefs\help.var"
                include "vardefs\window.var"
                include "vardefs\newkey.var"
                include "vardefs\mikey.var"
                include "vardefs\suzy.var"
                include "vardefs\font.var"

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		    Declare space for important game variables.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;	 

BEGIN_ZP
pos_x	  	    ds 1		; For starting character x position		   
pos_y		    ds 1		; For starting character y position   
walk_counter    ds 1		; For walking animation sprite counter
jump_height     ds 1	      ; For jumping height
up_or_down      ds 1	      ; For tracking up or downward movement.
horizon_y	    ds 1	      ; For y location of the horizon.
horizon_y2	    ds 1		; Just above the horizon
END_ZP

BEGIN_MEM
                align 4
screen0         ds SCREEN.LEN
screen1         ds SCREEN.LEN
coll            ds SCREEN.LEN
END_MEM

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		    Initilize lynx system, collision, display.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


                run LOMEM
Start::         START_UP
                CLEAR_MEM
                CLEAR_ZP +STACK
                INITMIKEY
                INITSUZY

		    HOME
		    MOVEI coll,$fc0a
		    lda #$ff
		    sta $fc24
		    sta $fc25
		    LDA #2
		    STA $fc92
		    STA _SPRSYS

		    INITFONT SMALLFNT,ROT,WEISS    ;For printing text
                SET_MINMAX 0,0,160,102
	
	
		    SETRGB pal		           ;Set palette

IF DOUBLEBUFFER
                SCRBASE screen0,screen1
ELSE
                SCRBASE screen0
ENDIF
IF DOUBLEBUFFER
                SWITCHBUF
ENDIF

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		    Initialize pos_x, pos_y starting positions.
;;              Align all the character sprites to this position.
;;		    Set character jumping height, horizon location.		    
;;
;;	          Feel free to change pos_x, pos_y, jump_height, and
;;		    horizon from #30, #10, #100 & #62 to other numbers,
;;		    based on the size of your own game sprites. For
;;		    reference, the included sprites are 80 by 80 pixels;
;;		    the size of the lynx screen is 160 by 102 pixels. 
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


		    LDA #30		   ;Set Starting character x position
		    STA pos_x
		    LDA #10		   ;Set Starting character y position
		    STA pos_y		
		    LDA #100	   ;Set Character jumping height
		    STA jump_height
		    LDA #62		   ;Set y location for the top of
		    STA horizon_y    ;the ground sprite.

;********************************************************************

  	          LDA #0		    
		    sta walk_counter  ; Counter for walking animation
		    sta up_or_down    ; Keeps track if character is
		  		          ; jumping up, or falling down:
			   	 	    ; 0= on the way up, or on ground
			  		    ; 1= falling down

		    LDA horizon_y	    ;Set the floor y location to 
		    STA floor_y	    ;our chosen horizon_y location.
		    STA floor2_y
		
		    LDA horizon_y	    ;Set horizon_y2 2 pixels above
		    STA horizon_y2    ;the real horizon_y.
		    dec horizon_y2
		    dec horizon_y2    

                lda pos_x	    ;Align all character sprites to
		    sta sit_x	    ;      the initial pos_x
		    sta stand_x
		    sta block_x
		    sta walk1_x
		    sta walk2_x
	   	    sta walk3_x
		    sta walk4_x
		    sta kick_x
		    sta punch_x
		    sta jump_x
		    sta sitblock_x
		    sta sitkick_x
		    sta sitpunch_x
		    sta hurt_x
		    sta spark_x
		    sta jkick_x
		    sta jpunch_x

                lda pos_y	    ;Align all character sprites to		  
		    sta sit_y	    ;      the initial pos_y
		    sta stand_y
		    sta block_y
		    sta walk1_y
		    sta walk2_y
	   	    sta walk3_y
		    sta walk4_y
		    sta kick_y
		    sta punch_y
		    sta jump_y
		    sta sitblock_y
		    sta sitkick_y
		    sta sitpunch_y
		    sta hurt_y
		    sta spark_y
		    sta jkick_y
		    sta jpunch_y

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		    Display the Title Screen.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

		    LDAY titleSCB		  ;Load titleSCB addresses.
		  			        ;  SCB's hold vital sprite 
			 			  ;  information. The SCBs are
				     		  ;  sprite control blocks, which
					        ;  are declared later in this
					        ;  program.
	          jsr DrawSprite	  ;Use DrawSprite subroutine
		  		              ;  to Draw title sprite.
						  ;  This subroutine is from
						  ;  the file: draw_spr.inc .

		    SET_XY 15,92          ;screen text print coordinates
                PRINT "Test Program: 11.27.00 VICK",,1

                SWITCHBUF		  ;Display the render buffer.
.wait1
	          READKEY 	        ;Loop until a button is
                lda Button		  ;pressed, to start game.
	          beq .wait1	

		    SWITCHBUF	

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		    Read button/cursor controls, and jump
;;              to the appropriate execution loop.		    
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

.begin_loop
.a0             READKEY         ; Macro from the file: MIKEY.MAC
			  		  ; READKEY checks what cursor or
				        ;    button is pressed on the lynx. 

                lda Cursor	  ; Check what direction on the 
		    CMP #$10	  ;    keypad was pressed. Then
		    BEQ aright	  ;    branch to the appropriate
		    CMP #$20	  ;    location: aright, for right		
		    BEQ aleft	  ;    keypad press, etc.
		    CMP #$40
		    BEQ adown
		    CMP #$80
		    BEQ aup
		    CMP #$50   
		    BEQ adownright
		    CMP #$60   
		    BEQ adownleft
		    CMP #$90   
		    BEQ aupright
		    CMP #$A0   
		    BEQ aupleft

		    lda Button	  ; Check what button was pressed
		    CMP #$1	        ;    on the lynx. Branch to the
		    BEQ apause      ;    appropriate location: to 
		    CMP #$2		  ;    apause for pause press,
		    BEQ aAbutton    ;    aAbutton for A button
		    CMP #$4		  ;    press, etc.
		    BEQ aBbutton
		    CMP #$8     
		    BEQ aopt1
		    CMP #16
		    BEQ aopt2

		    jmp aNONE	  ; Jump to aNONE, neither cursor
				        ;    nor button activity detected.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;              The labels below, aup, adown, aright, etc., are 
;;		    jumping boards to the up, down, right, etc. labels.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
		                    
aup		    jmp up          ; Jump to 'up' cursor case.
adown	    	    jmp down        ; Jump to 'down' cursor case.
aright	    jmp right	  ; Jump to 'right' cursor case.
aleft	    	    jmp left	  ; Jump to 'left' cursor case.
apause	    jmp pause	  ; Jump to 'pause' button case.
aBbutton        jmp Abutton     ; Jump to 'Abutton' button case.
aAbutton	    jmp Bbutton     ; Jump to 'Bbutton' button case.
aopt1	    	    jmp opt1	  ; Jump to 'opt1' button case.
aopt2	    	    jmp opt2	  ; Jump to 'opt2' button case'
adownright      jmp downright	  ; Jump to 'downright' cursor case.
adownleft	    jmp downleft	  ; Jump to 'downleft' cursor case.
aupright	    jmp upright	  ; Jump to 'upright' cursor case.
aupleft	    jmp upleft	  ; Jump to 'upleft' cursor case.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;              Cases for what to do, in the event of any 
;;		    cursor or button activity.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;******************************************************************
;***************What to do if: No button or cursor pressed*********
;******************************************************************
aNONE		    
		    LDA #0		       ;Once character stops walking,
		    sta walk_counter     ;   reset the walk animation
					       ;   counter to zero.

		    LDA floor_y          ;Check y position of floor.
		    CMP horizon_y2  	 ;   Compare it to the horizon.      
		    BNE .setfalling      ;If not equal: Branch setfalling.
 
		    LDA #0			 ;If they are equal:
		    STA up_or_down       ;Set up_or_down to 0. So you
		    jmp .loop1	 	 ;   are on the ground. 
					       ;   Then Jump to main loop1.

.setfalling     LDA #1		       ;Set up_or_down to 1. 
		    STA up_or_down	 ;This means you are falling.
		    jmp .loop1		 ;Jump to main loop1.


;******************************************************************
;***************What to do if: Pause button pressed****************
;******************************************************************
pause					
		    jmp .pauseloop	 ;Jump to pause execution loop,
						 ;     to pause the game.

;******************************************************************
;***************What to do if: Option 1 button pressed*************
;******************************************************************
opt1
		    jmp .opt1loop		 ;Jump to Opt1 execution loop.

;******************************************************************
;***************What to do if: Option 2 button pressed*************
;******************************************************************
opt2
		    jmp .opt2loop		 ;Jump to Opt2 execution loop.

;******************************************************************
;***************What to do if: B button pressed********************
;******************************************************************
Bbutton
		    LDA floor_y		;Check y postion of floor.
		    CMP horizon_y		;Compare it to the horizon.
		    BCS .airBbutton	;If floor_y >= horiz_y,
					      ;   branch to .airBbutton
		    jmp .Bbuttonloop    ;If floor_y < horiz_y, then:
					      ;B cursor press on ground.
				            ;Jump to Bbutton loop, to
						;draw the punch sprite.

.airBbutton     jmp Bbutton_jumppunch ;B cursor press in air.
						  ;Jump to air punch loop.
						  ;to draw air punch sprite.

;******************************************************************
;***************What to do if: A button pressed********************
;******************************************************************
Abutton
		    LDA floor_y		;Check y postion of floor.
		    CMP horizon_y		;Compare it to the horizon.
		    BCS .airAbutton  	;If floor_y >= horiz_y,
						;   branch to .airAbutton
		    jmp .Abuttonloop	;If floor_y < horiz_y, then:
					      ;A cursor press on ground.
				            ;Jump to Abutton loop, to
						;draw the kick sprite. 

.airAbutton     jmp Abutton_jumpkick ;B cursor press in air.
				             ;Jump to air kick loop,
						 ;to draw the air kick sprite.

;******************************************************************
;***************What to do if: Up cursor pressed*******************
;******************************************************************
up
		    LDA floor_y		;Check y postion of floor.
		    CMP horizon_y2  	;Compare it to the horizon.
		    BNE .setdown		;If floor_y != horiz_y2,
					      ;   jump .setdown. You're
					      ;   already in the air then.

		    LDA #0		      ;Not in the air yet? Then
		    STA up_or_down	;   set up_or_down to 0.
.setdown
		    LDA up_or_down	;Check if character is on
		    CMP #0			;way up(0) or down(1).
		    BNE .nomoreup		;If he is on the way up (0)
						;then branch to .nomoreup.
					      ;So you can only jump once.

		    LDA floor_y		;Check y postion of floor.
		    CMP jump_height	;Compare it to jump_height.
		    BCS .nomoreup		;If floor_y >= jump_height,
						;   then you already reached
						;   the peak of your jump. 
					      ;   You need to stop moving
						;   up. Branch to .nomoreup

		    inc floor_y 		;If floor_y < jump_height
		    inc floor_y		;   then you are still going
		    				;   up on your jump. To achieve
		    				;   this illusion, increase the
	          inc moon_y		;   y position of the floor,
 	          inc moon_y		;   moon, and fireball, so they
		    inc fire_y		;   move down the screen, and
		    inc fire_y		;   you appear to move 'up.'
		    jmp .stillgoingup   ;   Jump to .stillgoing up
.nomoreup
		    LDA #1			;You have reached your jump
		    sta up_or_down	;   peak. Set up_or_down to 1.
.stillgoingup
		    jmp .uploop		;Finally, jump to the uploop
						;   main loop. So the proper
						;   jump sprites can be drawn.

;******************************************************************
;***************What to do if: Down cursor pressed*****************
;******************************************************************
down		    				;Jump the the main downloop,
		    jmp .downloop		;to draw the character sitting.

;******************************************************************
;***************What to do if: Right cursor pressed****************
;******************************************************************
right
		    LDA floor_y		;Check y postion of floor.
		    CMP horizon_y		;Compare it to the horizon.
	          BCS .norightairwalk ;If floor_y >= horizon_y,
						;   then you're pressing 
						;   right while you're in 
						;   the air. Branch over to
						;   .norightairwalk.

		    inc walk_counter    ;If floor_y < horizon_y, then 
		    dec floor_x		;   the character is merely
		    dec floor2_x		;   walking to the right. To
		    dec fire_x		;   switch frames in the
						;   animation, increase the
						;   walk_counter, to make 
						;   the ground move to the
						;   left, dec the floor_x
						;   location. Also, decrease
						;   fire_x to make the fireball
						;   fly to the left.

		    jmp .rightloop	;Now, jump to the rightloop,
						;   so proper new sprites 
						;   can be drawn.

.norightairwalk
		    dec floor_x		;You pressed right while in
		    dec floor_x		;    the air. He needs to 
		    dec floor2_x		;    'fall' to the right.
		    dec floor2_x        ;    So move floor to left.
					      ;Also, scroll the background
		    dec moon_x		;    moon, by decreasing
						;    its x position.

		    jmp .loop1		;Jump to main .loop1. No change
						;    in actual character
						;    sprites, only location
						;    changes.

;******************************************************************
;***************What to do if: Left cursor pressed*****************
;******************************************************************
left						;Jump to .leftloop loop.
		    jmp .leftloop

;******************************************************************
;***************What to do if: Down right cursor pressed***********
;******************************************************************
downright					
		    jmp .downrightloop	;Jump to .downrightloop loop.
		    
;******************************************************************
;***************What to do if: Down left cursor pressed************
;******************************************************************
downleft					
		    jmp .downleftloop   ;Jump to .downleftloop loop.

;******************************************************************
;***************What to do if: Up right cursor pressed*************
;******************************************************************
upright
		    LDA floor_y		;Check y postion of floor.
		    CMP horizon_y2      ;Compare it to the horizon.
		    BNE .setdown2		;If not equal, then you're
						;   in the air. Branch to
						;   setdown2.

		    LDA #0			;If you're not already in
		    STA up_or_down	;   the air. Set up_or_down
						;   to 0.
.setdown2
		    LDA up_or_down      ;Check value of up_or_down
		    CMP #0			;Compare it to zero.
		    BNE .nomoreupright  ;If it is not zero, then
						;   you are falling. Branch
						;   to .nomoreupright

		    LDA floor_y		;Check value of floor_y 
		    CMP jump_height	;Compare it to jump height.
		    BCS .nomoreupright	;If floor_y >= jump_height,
						;   then you already reached
						;   your jump peak. Stop
						;   moving up right. Branch
						;   to .nomoreupright.  

		    inc floor_y 		;If floor_y < jump_height,
		    inc floor_y		;   then you need to move
		    dec floor_x		;   to the upright. Thus,
		    dec floor_x		;   the background/floor
		    dec floor2_x		;   needs to move to the
		    dec floor2_x		;   down left. So decrease
	          inc moon_y		;   x's (left movement)
		    inc moon_y		;   and increase the y's
		    dec moon_x		;   (down movement).
		    inc fire_y		
		    inc fire_y		
		    dec fire_x		
		    dec fire_x

		    jmp .stillgoingupright

.nomoreupright
		    LDA #1			;Character is falling now,
		    STA up_or_down	;    so set up_or_down to 1.

.stillgoingupright
		    jmp .uploop		;Jump to the main uploop,
						;    to execute these
						;    changes.

;******************************************************************
;***************What to do if: Up left cursor pressed**************
;******************************************************************
upleft					
		    jmp .upleftloop     ;Jump to .upleftloop loop.

;******************************************************************
;***************END of button/cursor cases.************************
;******************************************************************


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;		    Main program loops to execute actions.		    
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;********************************************************************
;		     For when no button/cursor is being pressed.
;********************************************************************

.loop1
		     LDA floor_y		;Check value of floor_y.
		     CMP horizon_y  	;Compare it to horizon_y
		     BCC .lowerfloor	;If floor_y < horizon_y
						;   branch to .lowerfloor.
						 
		     dec floor_y		;If floor_y >= horizon_y
	  	     dec floor_y		;   then make the floor,
	  	     dec moon_y		;   moon, and fireball
		     dec moon_y		;   scroll up.
		     dec fire_y
		     dec fire_y

		     LDA floor_y		;Check value of floor_y.
		     CMP horizon_y	;Compare it to horizon_y
		     BNE .notonfloor	;If floor_y not eq horizon_y
					      ;then branch to .notonfloor

		     LDA #0			;If floor_y = horizon_y,
		     STA up_or_down	;then you are on the ground,
						;so set up_or_down = 0.

.notonfloor					;In the air, no button/cursor
						;   being pressed.

		     CLS 0			;Clear the screen.
		     jsr DrawFloor	;Use DrawFloor subroutine
						;    from later in this 
						;    program to draw floor
						;    at proper coordinates.
		     LDAY jumpSCB		;Load addresses of jumpSCB
		     jsr DrawSprite 	;Use DrawSprite subroutine
						;    to draw this sprite.
		     jmp .loop4		;Finally, done, so jump to
						;    end of main loop, .loop4.
 
.lowerfloor
		     LDA firecol		;Check value of fireball
						;    collision depository. 
		     CMP #1			;Compare it to one.
		     BEQ .fireballhit   ;If firecol = 1, then the
						;    fireball collided with
						;    the standing character;
					      ;    Look at SCBs, later, to
					      ;    see that only the stand
						;    sprite has a Collision
					      ;    number of 1. So the
						;    fireball can't hit any
					      ;    other sprite. Unless you
						;    change that. Change all
						;    the collision numbers to
						;    1, and the fireball hits
						;    all of the sprites.
						;    Branch to .fireballhit

		     jmp .nofireballhit ;If firecol not eq 1, then
						;   fireball did not collide
						;   with the standing char.;
						;   branch to .nofireballhit

.fireballhit				;Got hit with fireball.
		     CLS 0			;Clear screen.
		     jsr DrawFloor	;Draw the floor.
		     LDAY hurtSCB		;Load addresses of hurt char.
		     jsr DrawSprite	;Draw hurt character sprite.
		     jmp .loop3		;Jump end of main loop, .loop3

.nofireballhit				;Did not get hit with fireball.
		     CLS 0			;Clear screen.
		     jsr DrawFloor	;Draw the floor.
		     LDAY standSCB	;Load addresses of standing
						;     character sprite.
		     jsr DrawSprite	;Draw stand character sprite.
		     jmp .loop3		;Jump end of main loop, .loop3

;********************************************************************
;		     For when pause button was pressed.
;********************************************************************
.pauseloop					
		     LDAY pauseSCB	;Load pauseSCB addresses
		     jsr DrawSprite	;Render the pause sprite. 
                 SWITCHBUF		;Show buffer sprite was
						;     rendered into.
.pauseloop2
	           READKEY 		;Loop (stay paused) until
                 lda Cursor		;     the player pushes 
                 beq .pauseloop2	;     the cursor.

                 SWITCHBUF		;Switch back to the
						;     other buffer.
		     jmp .loop3

;********************************************************************
;		     For when option 1 button was pressed.
;********************************************************************
.opt1loop					;At present, option 1 has no
						;   effect, if you press it
						;   all by itself.
		     jmp .loop1		;Jump to main loop, .loop1
						;   as if no button was pushed.
		     ;jmp .loop3		;Use jump to .loop3 when you
						;   choose to make opt1 
						;   'do something.'

;********************************************************************
;		     For when option 2 button was pressed.
;********************************************************************
.opt2loop
		    			      ;Nothing happens here yet,
						;when you press option 2.
						;Feel free to code something.
		    jmp .loop1
		    ;jmp .loop3		

;********************************************************************
;		     For when up cursor was pressed.
;********************************************************************    		     
.uploop
						   ;Check if a button has been
		     lda Button		   ;     simultaneously pressed
						   ;     with the up cursor.
		     CMP #$4		   ;Compare to Abutton value
		     BEQ Abutton_jumpkick  ;If equal, branch jump kick, 
						   ;     UP + A button.
		     CMP #$2		   ;Compare to Bbutton value
		     BEQ Bbutton_jumppunch ;If equal, branch jump punch,
						   ;     UP + B button.
		     jmp .enduploop	   ;If neither A or B button
						   ;     is pressed at same
						   ;     time as up, then
					         ;	   branch to .enduploop

Abutton_jumpkick				   ;For kicking in the air.
		     jsr Scroll		   ;Use Scroll subroutine
						   ;     from later in program
						   ;     to scroll background.
		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.
		     LDAY jkickSCB	   ;Load addresses of jump kick
						   ;     sprite.
		     jsr DrawSprite	   ;Draw jump kick sprite.
		     jmp .loop4		   ;Jump to end of main loop.
						  

Bbutton_jumppunch				   ;For punching in the air.
		     jsr Scroll		   ;Use Scroll subroutine
						   ;     from later in program
						   ;     to scroll background.
		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.
		     LDAY jpunchSCB	   ;Load addresses of jump 
						   ;     punch sprite.
		     jsr DrawSprite	   ;Draw jump kick sprite.
		     jmp .loop4		   ;Jump to end of main loop.

.enduploop					   ;Only up cursor was pressed,
						   ;     i.e., no buttons.
		     LDA up_or_down	   ;Check value of up_or_down.
		     CMP #0			   ;Compare it to zero.
		     BEQ .goingup 	   ;If it equals zero, character
						   ;     is on ground, or on
						   ;     way up in jump, so
					         ;     branch to .goingup

						   ;up_or_down not equal 0,
						   ;     so character is falling.		     
		     LDA floor_y		   ;Check floor y position.
		     CMP horizon_y  	   ;Compare it to horizon.
		     BCC .endfall		   ;If floor_y < horizon_y,
						   ;     the character has
						   ;     hit the ground. So
						   ;     branch to .donefall.	   

		     dec floor_y		   ;Character is still falling
	  	     dec floor_y		   ;     so decrease y positions
	  	     dec moon_y		   ;     of floor, moon, and
		     dec moon_y		   ;     fireball, so character
		     dec fire_y		   ;     'falls' closer to
		     dec fire_y		   ;     the ground.
		     jmp .endfall
.donefall 	     jmp .loop1
.goingup
.endfall
		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.
		     LDAY jumpSCB		   ;Load jump sprite addresses.
		     jsr DrawSprite	   ;Draw the jump sprite.
		     jmp .loop4		   ;Jump to end of main loop.

;********************************************************************
;		     For when down cursor was pressed.
;********************************************************************
.downloop
		     jsr Scroll		   ;Use subroutine to scroll 
						   ;background positions.
 
 		     lda Button		   ;Check if a button has
		     CMP #$4		   ;    been pressed too.
		     BEQ Abutton_sitkick   ;If A, branch to sit kick
		     CMP #$2
		     BEQ Bbutton_sitpunch  ;If B, branch to sit punch
		     CMP #16
		     BEQ Opt2_spark	   ;If option 1, branch to
						   ;    sparking character.

		     	 		         ;No button was pressed
						   ;    at same time as down,
					         ;    so only execute sit.

		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.
		     LDAY sitSCB		   ;Load sit sprite addresses.
		     jsr DrawSprite	   ;Draw the sit sprite.

		     jmp .loop3		   ;Jump to end of main loop.

Abutton_sitkick			         ;Execute sit kick.
		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.
		     LDAY sitkickSCB	   ;Load sitkick addresses.
		     jsr DrawSprite	   ;Draw sit kick sprite.
		     jmp .loop3		   ;Jump to end of main loop.

Bbutton_sitpunch			   	   ;Execute sit punch.
		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.
		     LDAY sitpunchSCB	   ;Load sitpunch addresses.
		     jsr DrawSprite	   ;Draw sit punch sprite.
		     jmp .loop3		   ;Jump to end of main loop.

Opt2_spark					   ;Execute special electricity
						   ;    technique.
		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.		
		     LDAY sparkSCB	   ;Load spark addresses.
		     jsr DrawSprite	   ;Draw the sparking character.
		     jmp .loop3		   ;Jump to end of main loop.

;********************************************************************
;		     For when B button was pressed all by itself.
;********************************************************************

.Bbuttonloop
		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.
		     LDAY punchSCB	   ;Load punch addresses.
		     jsr DrawSprite	   ;Draw the punching sprite.
		     jmp .loop3		   ;Jump to end of main loop.

;********************************************************************
;		     For when A button was pressed all by itself.
;********************************************************************

.Abuttonloop
		     CLS 0			   ;Clear the screen.
		     jsr DrawFloor	   ;Draw the floor.
		     LDAY kickSCB		   ;Load kick addresses.
		     jsr DrawSprite	   ;Draw the kicking sprite.
		     jmp .loop3		   ;Jump to end of main loop.

;********************************************************************
;		     For when right cursor was pressed.
;********************************************************************
.rightloop
		    jsr Scroll		   ;Use Scroll subroutine to scroll
						   ;    background positions.

		    LDA walk_counter	   ;Check value of walk_counter.
		    CMP #3			   ;If < 3, 
		    BCC .walkeast1	   ;Branch to 1st walk animation.
		    CMP #7			   ;If >= 3, and < 7,
		    BCC .walkeast2	   ;Branch to 2nd walk animation.
		    CMP #11			   ;If >= 7, and <11,
		    BCC .walkeast3	   ;Branch to 3rd walk animation.
		    CMP #15			   ;If >= 11, and <15
		    BCC .walkeast4	   ;Branch to 4th walk animation.
		    CMP #15			   ;If = 15,
		    BEQ .walkrestart	   ;Branch to restart animation.

.walkeast1					   ;1st walk animation.
		    CLS 0			   ;Clear screen.
		    jsr DrawFloor		   ;Draw the floor.
		    LDAY walk1SCB		   ;Load walk1 addresses.
		    jsr DrawSprite	   ;Draw the walk1 sprite.
		    jmp .loop3		   ;Jump to end of main loop.

.walkeast2					   ;2nd walk animation.
		    CLS 0			   ;Clear screen.
		    jsr DrawFloor		   ;Draw the floor.
		    LDAY walk2SCB		   ;Load walk2 addresses.
		    jsr DrawSprite	   ;Draw the walk2 sprite.
		    jmp .loop3		   ;Jump to end of main loop.

.walkeast3					   ;3rd walk animation.
		    CLS 0			   ;Clear screen.
		    jsr DrawFloor		   ;Draw the floor.
		    LDAY walk3SCB		   ;Load walk3 addresses.
		    jsr DrawSprite	   ;Draw the walk3 sprite.
		    jmp .loop3		   ;Jump to end of main loop.

.walkeast4					   ;4th walk animation.
		    CLS 0			   ;Clear screen.
		    jsr DrawFloor		   ;Draw the floor.
		    LDAY walk4SCB		   ;Load walk4 addresses.
		    jsr DrawSprite	   ;Draw the walk4 sprite.
		    jmp .loop3		   ;Jump to end of main loop.

.walkrestart				   ;Restart walk animations.
		    LDA #0			   
		    sta walk_counter	   ;Set walk_counter to zero.

		    dec moon_x 		   ;Scroll the moon just once
					         ;    per complete walk cycle,
						   ;    so that it scrolls
						   ;    slower than the 
						   ;    forground.
		    jmp .rightloop	   ;Walk counter has been reset,
						   ;    no jump to the beginning
						   ;    of .rightloop, to draw
						   ;    the first animation frame.

;********************************************************************
;		     For when left cursor was pressed.
;********************************************************************

.leftloop	    
		    jsr Scroll		   ;Use scroll subroutine to scroll
						   ;    background positions.

		    CLS 0			   ;Clear the screen.
		    jsr DrawFloor		   ;Draw the floor.
		    LDAY blockSCB		   ;Load addresses of block sprite.
		    jsr DrawSprite	   ;Draw blocking character sprite.
		    jmp .loop3		   ;Jump to end of main loop.

;********************************************************************
;		     For when down right was pressed.
;********************************************************************
.downrightloop			  ;Nothing happens here yet.
					  ;Make something happen.
		    jmp .loop1      ;Jump to beginning of main .loop1,
		    ;jmp .loop3	  ;     as if nothing was pressed.

;********************************************************************
;		     For when down left was pressed.
;********************************************************************
.downleftloop
		    jsr Scroll		;Use Scroll subroutine to scroll
					      ;    background positions.

		    CLS 0		      ;Clear the screen.
		    jsr DrawFloor	      ;Draw the floor.
		    LDAY sitblockSCB	;Load sitblock addresses.
		    jsr DrawSprite	;Draw the sitblock sprite.
		    jmp .loop3		;Jump to end of main loop.

;********************************************************************
;		     For when up right cursor was pressed.
;********************************************************************
.uprightloop
		    jsr Scroll		;Use scroll subroutine to scroll
					      ;    background positions.

		    CLS 0			;Clear the screen.
		    jsr DrawFloor		;Draw the floor.
		    LDAY jumpSCB		;Load addresses of jump sprite.
		    jsr DrawSprite	;Draw the jump sprite.
		    jmp .loop3		;Jump to end of main loop.

;********************************************************************
;		     For when up left cursor was pressed.
;********************************************************************
.upleftloop					;Nothing happens here yet.
						;Feel free to make it do
						;something.
		    jmp .loop1   		;Jump to beginning of main
		    ;jmp .loop3		;     loop, as if no cursor
						;     was pressed.

;********************************************************************
;		     End of main execution loop.
;********************************************************************
.loop3
.loop4
	          dec fire_x		;Scroll the fireball to the
						;    left once, for each time
						;    the main loop completes.
		    LDAY fireSCB		;Load fireball addresses.    
						
		    jsr DrawSprite	;Draw the fireball.


IF DOUBLEBUFFER
                SWITCHBUF		;Switch buffers to show what
ENDIF						;    was drawn.
		    jmp .begin_loop	;Jump to .begin_loop, to
					      ;    start the whole process
						;    over, and check the next 
						;    cursor/button action.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;		     
;;		    Subroutines written specifically for this
;;		    program.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

DrawFloor::
		    LDA floor_y		;Align the y position of the
		    STA floor2_y		;     two floor sprites.

		    LDAY floor2SCB	;Load floor2 addresses.
		    jsr DrawSprite	;Draw floor2 sprite.
	
		    LDAY floorSCB		;Load floor addresses.
		    jsr DrawSprite	;Draw floor sprite.

		    LDAY moonSCB		;Load moon addresses.
		    jsr DrawSprite	;Draw the moon sprite.
		    rts		      ;Return to program, from
						;    this subroutine.

Scroll::
		     LDA floor_y		;Check y position of floor.
		     CMP horizon_y  	;Compare it to the horizon.
		     BCC .nodownscroll  ;If floor_y < horizon_y
						;then character is on the
						;ground, and no need to 
						;do any vertical scrolling.

		     dec floor_y		;Character is not on the
	  	     dec floor_y		;ground, so vertical scroll.
	  	     dec moon_y		;Decreasing the y positions
		     dec moon_y		;of the floor, moon, and
		     dec fire_y		;fireball, will make the
		     dec fire_y		;character 'fall.'

.nodownscroll
		     LDA #0			;Set up_or_down to 0. 
		     STA up_or_down		
		     rts

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;		     
;;		    Below, are all the sprite control blocks,
;;		    (SCB)s used in this program. Only the first SCB,
;;		    standSCB, will have a description of what each 
;;		    value means. But it applies to all of them.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

standcol	    db 0			  ;Collision depository.
						  ;When this sprite hits 
						  ;   something, the other
						  ;   sprite's collision
						  ;   number will fall in here.

standSCB        dc.b $c7		  ;SPRCTLO control.
						  ;For declaring the number
						  ;    of colors in this
						  ;    sprite's data file,
						  ;    and what type of sprite
						  ;    this is.
						  ;    $c? means 16 colors.     
					        ;    $8? ---->  8 colors.
						  ;    $4? ---->  4 colors.
						  ;    $0? ---->  2 colors.
						  ;    $?7 means Normal sprite.
						  ;    $?6 ----> XOR sprite.
						  ;    $?5 ----> Non-colliding.
						  ;    $?4 ----> Shadow sprite.
						  ;    $?3 ----> BGroundShadow
						  ;    $?2 ----> Boundry sprite.
						  ;    $?1 ----> BGroundNonCol.
						  ;    $?0 ----> BackGround
						  ;Based on the above, we can
						  ;  see that this sprite: $c7,
						  ;  has 16 colors, and is a
						  ;  normal sprite. Notice later,
						  ;  that the title screen is $c1.
						  ;  This gets drawn much faster
						  ;  than a $c7.
						  ;For more information about
						  ;  these sprite types, read the
						  ;  the complete lynx documentation
						  ;  at 42Bastian's page:
      ;http://www.geocities.com/SiliconValley/Byte/4242/lynx/lynxdoc.html

		    dc.b $00		  ;SCBCTL1 control.
						  ;Deals with reloading of
						  ;sprite data:
						  ;Reload none = $0?
						  ;Reload HV   = $1?
						  ;Reload HVS  = $3?
						  ;Reload HVST = $4?
						  ;Reuse_Palette = $?8
						  ;Skip_Sprite   = $?4
						  ;H is Horizontal scaling
						  ;V is Vertical scaling
						  ;S is stretch
						  ;T is tile.
						  ;Our value of $00, means
						  ;reload none.
						  ;Change to $10, for 
						  ;example, to enable
						  ;Horizontal and vertical
						  ;scaling.


		    dc.b $01		  ;SPRCOLL.
						  ;This is this sprite's
						  ;     collision number.

                dc.w 0		        ;When you want to paint
						  ;many sprites in a row,
						  ;this points to the next
						  ;sprite you intend to 
						  ;paint, to speed things up.
						  ;0 means doesn't draw any
						  ;sprite next. Change 0
						  ;to blockSCB, for example,
						  ;and the blocking sprite
						  ;would be drawn immediately
						  ;after this one.

                dc.w stand_sprite     ;Location of actual data
						  ;for this specific sprite.
						  ;This points to this data
						  ;file at the end of this
						  ;program.

stand_x	    dc.w 10			  ;X position of this sprite.
stand_y	    dc.w 10			  ;Y position of this sprite.

		    ;dc.w $100		  ;Horizontal scale value,
						  ;Not used in this program.
		    ;dc.w $100		  ;Vertical scale value,
						  ;Not used in this program.
		    ;dw.w 0			  ;Stretch value, not used here.
		    ;dc.w 0		        ;Tilt value, not used here.
		
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00 ;--->palette color# 
		    ;     01, 23, 45, 67, 89, AB, CD, EF  --->sprite index#

						  ;This is the pen palette here.
					        ;It tells the program what
						  ;   color (from the palette
					        ;   at the end of this program)
					        ;   that the pixels of your
						  ;   sprite will be.
						  ;For example, all the pixels
						  ;   from this sprite, with
						  ;   a sprite index value of 0, 
					        ;   will be painted with 
						  ;   palette color "D". 
						  ;   See the palette below.
						  ;   Likewise, sprite indexes
						  ;   C,D,E,F are painted with 
						  ;   palette color 0 (clear).
						  ;   And index 6 is painted 
						  ;   with palette color 6.
						  ;By changing these numbers,
						  ;   the same sprite can be drawn
						  ;   in numerous different colors.
						  ;For more understandable info
						  ;   on this, check the lynx
						  ;   reference manual at 
						  ;   42Bastian's page.
	   ;http://www.geocities.com/SiliconValley/Byte/4242/lynx/lynxdoc.html
  

blockcol	    db 0
blockSCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w block_sprite
block_x	    dc.w 10
block_y	    dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

sitblockcol	    db 0
sitblockSCB     dc.b $c7,$00,$00
                dc.w 0
                dc.w sitbl_sprite
sitblock_x	    dc.w 10
sitblock_y	    dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

kickcol	    db 0
kickSCB         dc.b $c7,$00,$00
                dc.w 0
                dc.w kick_sprite
kick_x	    dc.w 10
kick_y	    dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

punchcol	    db 0
punchSCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w punch_sprite
punch_x	    dc.w 10
punch_y	    dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

sitcol	    db 0
sitSCB          dc.b $c7,$00,$00
                dc.w 0
                dc.w sit_sprite
sit_x  	    dc.w 10
sit_y	          dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

jumpcol	    db 0
jumpSCB         dc.b $c7,$00,$00
                dc.w 0
                dc.w jump_sprite
jump_x  	    dc.w 10
jump_y          dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

sitkickcol	    db 0
sitkickSCB      dc.b $c7,$00,$00
                dc.w 0
                dc.w sitkick_sprite
sitkick_x  	    dc.w 10
sitkick_y       dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

sitpunchcol	    db 0
sitpunchSCB     dc.b $c7,$00,$00
                dc.w 0
                dc.w sitpunch_spr
sitpunch_x 	    dc.w 10
sitpunch_y      dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

hurtcol	    db 0
hurtSCB         dc.b $c7,$00,$01
                dc.w 0
                dc.w hurt_sprite
hurt_x	    dc.w 10
hurt_y	    dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00 

sparkcol	    db 0
sparkSCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w spark_sprite
spark_x	    dc.w 10
spark_y	    dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

jkickcol	    db 0
jkickSCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w jkick_sprite
jkick_x	    dc.w 10
jkick_y	    dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

jpunchcol	    db 0
jpunchSCB       dc.b $c7,$00,$00
                dc.w 0
                dc.w jpunch_sprite
jpunch_x	    dc.w 10
jpunch_y	    dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$AB,$00,$00

walk1col	    db 0
walk1SCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w walk1_sprite
walk1_x  	    dc.w 10
walk1_y         dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$A0,$00,$00

walk2col	    db 0
walk2SCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w walk2_sprite
walk2_x  	    dc.w 10
walk2_y         dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$A0,$00,$00

walk3col	    db 0
walk3SCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w walk3_sprite
walk3_x  	    dc.w 10
walk3_y         dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$A0,$00,$00

walk4col	    db 0
walk4SCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w walk4_sprite
walk4_x  	    dc.w 10
walk4_y         dc.w 10
		    dc.b $D1,$23,$45,$67,$89,$A0,$00,$00

floorcol	    db 0
floorSCB        dc.b $c1,$00,$00
                dc.w 0
                dc.w floor_sprite
floor_x  	    dc.w 255
floor_y         dc.w 62
		    dc.b $01,$C5,$EF,$67,$89,$A0,$00,$00

floor2col	    db 0
floor2SCB       dc.b $c1,$00,$00
                dc.w 0
                dc.w floor_sprite
floor2_x  	    dc.w 127
floor2_y        dc.w 62
		    dc.b $01,$C5,$EF,$67,$89,$A0,$00,$00

mooncol	    db 0
moonSCB         dc.b $c7,$00,$00
                dc.w 0
                dc.w moon_sprite
moon_x  	    dc.w 175
moon_y          dc.w 20
		    dc.b $01,$2E,$F0,$00,$00,$00,$00,$00

firecol	    db 0
fireSCB         dc.b $c7,$00,$00
                dc.w 0
                dc.w fire_sprite
fire_x  	    dc.w 100
fire_y          dc.w 25
		    dc.b $01,$45,$68,$9A,$00,$00,$00,$00

pausecol	    db 0
pauseSCB        dc.b $c7,$00,$00
                dc.w 0
                dc.w pause_sprite
	  	    dc.w 48
	          dc.w 0
		    dc.b $06,$89,$00,$00,$00,$00,$00,$00

titlecol	    db 0
titleSCB        dc.b $c1,$00,$00
                dc.w 0
                dc.w title_sprite
	  	    dc.w 0
	          dc.w 0
		    dc.b $01,$23,$45,$67,$89,$AB,$EF,$00  

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;		     
;;		    Include these useful files from the
;;		    lynx bll kit.	
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
						  
                include "includes\window2.inc"
                include "includes\random.inc"
                include "includes\newkey.inc"
                include "includes\hexdez.inc"
                include "includes\font.inc"
                include "includes\draw_spr.inc"  ;For drawing sprites.
                include "includes\font2.hlp"

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;		     
;;		    This is the palette for this program.
;;		    While there is only one here, you can
;;		    have multiple palettes and switch between
;;		    them in a program, if you want. Make 
;;		    another one called pal2, pal3, etc., if
;;		    you like. It uses a useful Macro 'DP',
;;		    to properly define the colors you choose.	
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

          ALIGN 4
pal DP 000,005,555,5B5,00B,50B,00F,50F,B0F,F5F,FBF,FFF,505,000,B0B,FBF
;color#: 0,  1,  2,  3,  4,  5,  6,  7,  8,  9,  A,  B,  C,  D,  E,  F

;Each palette color is defined by three numbers, color #4 = 005,
;     color #E=BOB, for example. These three numbers stand for
;	Green, Blue, and Red (GBR) brightnesses for a color.
;	For example, palette color #1 = 005 = dark red
;		       palette color #6 = 00F = bright red      		    
;			 pallete color #B = FFF = bright in all RGB = white
;			 pallete color #D = 000 = dark in all RGB = black
;                  pallete color #E = B0B = bright green + bright red
;						      = yellow
;	Practically any color you can
;     imagine can be made this way. 
;     555 would be a dark grey,
;     BBB would be a bright grey,
;     F00 would be a bright green, etc.
;    
;     Have fun changing the palette colors, to see how it effects
;	the color of the game sprites.


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;		     
;;		    Pointers to the actual sprite files
;;		    on your computer. Make sure the paths
;;		    are correct.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


stand_sprite   ibytes "sprites\blstand.spr"
block_sprite   ibytes "sprites\blblock.spr"
sitbl_sprite   ibytes "sprites\blsitblock.spr"
kick_sprite    ibytes "sprites\blkick.spr"
punch_sprite   ibytes "sprites\blpunch.spr"
sit_sprite     ibytes "sprites\blsit.spr"
jump_sprite	   ibytes "sprites\bljump.spr"
sitkick_sprite ibytes "sprites\blsitkick.spr"
sitpunch_spr   ibytes "sprites\blsitpunch.spr"
hurt_sprite    ibytes "sprites\blhurt.spr"
spark_sprite   ibytes "sprites\blspark.spr"
jkick_sprite   ibytes "sprites\bljumpkick.spr"
jpunch_sprite  ibytes "sprites\bljumppunch.spr"
walk1_sprite   ibytes "sprites\blwalk1.spr"
walk2_sprite   ibytes "sprites\blwalk2.spr"
walk3_sprite   ibytes "sprites\blwalk3.spr"
walk4_sprite   ibytes "sprites\blwalk4.spr"
floor_sprite   ibytes "sprites\blfloor.spr"
moon_sprite    ibytes "sprites\blmoon.spr"
fire_sprite    ibytes "sprites\blfireball.spr"
pause_sprite   ibytes "sprites\blpause.spr"
title_sprite   ibytes "sprites\titlescreen.spr"

END		   ;Finally! The end of this lynx program!

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;********************************************************************		     
;;*		    
;;*		    Any questions, comments or suggestions?	
;;*		    Did this program make you want to make your
;;*		    own lynx game? Did you actually try to compile
;;*             this program for yourself, to see if it works?
;;*  		    Feel free to let me know! Feel free to send 
;;*		    me the demos you make from this, with your
;;*  		    own sprites. I'd like to try it out, really!
;;*             Even if you only want to make fun of my
;;*             primitive programming style, write me. But 
;;*             above all, have fun, and help keep the 
;;*		    Atari Lynx alive. Here is my address:
;;*		                      nimtene@ juno.com    
;;*
;;*
;;********************************************************************
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;